@@ -2,7 +2,7 @@ package AxKit::XSP::Handel::Cart;
 use strict;
 use warnings;
 use vars qw($NS);
-use Handel::Constants qw(:cart);
+use Handel::Constants qw(:cart str_to_const);
 use Handel::Exception;
 use Handel::L10N qw(translate);
 use base 'Apache::AxKit::Language::XSP';
@@ -22,6 +22,10 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
 
         return unless length($text);
 
+        if ($tag eq 'type' && $text =~ /^[A-Z]{1}/) {
+            $text = str_to_const($text);
+        };
+
         if ($tag =~ /^(description|id|name|shopper|type)$/) {
             if ($context[$#context] eq 'new') {
                 return ".q|$text|";
@@ -51,6 +55,12 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
 
         AxKit::Debug(5, "[Handel] parse_start [$tag] context: " . join('->', @context));
 
+        if (exists $attr{'type'}) {
+            if ($attr{'type'} =~ /^[A-Z]{1}/) {
+                $attr{'type'} = str_to_const($attr{'type'});
+            };
+        };
+
         ## cart:uuid
         if ($tag =~ /^(g|u)uid$/) {
             $e->start_expr($tag);
@@ -81,12 +91,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Cart';
 
             push @context, $tag;
 
-            my $mode = $attr{'mode'} || 'CART_MODE_APPEND';
-            if (Handel::Constants->can($mode)) {
-                $mode = Handel::Constants->$mode;
-            } else {
-                $mode = CART_MODE_APPEND;
-            };
+            my $mode = str_to_const($attr{'mode'}) || CART_MODE_APPEND;
             delete $attr{'mode'};
 
             my $code .= scalar keys %attr ?
@@ -678,7 +683,7 @@ AxKit::XSP::Handel::Cart - AxKit XSP Shopping Cart Taglib
 
 =head1 VERSION
 
-    $Id: Cart.pm 215 2005-02-21 01:11:44Z claco $
+    $Id: Cart.pm 248 2005-02-28 02:42:30Z claco $
 
 =head1 SYNOPSIS
 
@@ -728,6 +733,21 @@ Add the namespace to your XSP file and use the tags:
 This tag library provides an interface to use L<Handel::Cart> inside of your
 AxKit XSP pages.
 
+=head1 CHANGES
+
+Starting in version C<0.09>, C<E<lt>cart:typeE<gt>>, the <type> attribute, and the C<mode>
+attribute in C<E<lt>cart:restore<gt>> now take the constants declared in C<Handel::Constants>:
+
+    <cart:type>CART_TYPE_SAVED</cart:type>
+
+    <cart:new type="CART_TYPE_SAVED">
+        ...
+    </cart:new>
+
+    <cart:restore mode="CART_MODE_APPEND">
+        ...
+    </cart:restore>
+
 =head1 TAG HIERARCHY
 
     <cart:uuid/>
